@@ -80,7 +80,6 @@ def parse_scan_config(wrapper: ParseConfigWrapper, models: dict[str, ScanModelCo
         mesh_direction=get_choice(wrapper, "mesh_direction", _directions, default="x"),
         mesh_height=wrapper.get_float("mesh_height", default=4, minimum=1),
         mesh_path=get_choice(wrapper, "mesh_path", _paths, default="snake"),
-        mesh_corner_radius=wrapper.get_float("mesh_corner_radius", default=2, minimum=0),
     )
 
 
@@ -89,6 +88,7 @@ def parse_touch_config(wrapper: ParseConfigWrapper, models: dict[str, TouchModel
     return TouchConfig(
         samples=samples,
         max_samples=wrapper.get_int("max_samples", default=samples * 2),
+        max_touch_temperature=wrapper.get_int("UNSAFE_max_touch_temperature", default=150),
         models=models,
     )
 
@@ -100,7 +100,7 @@ def parse_bed_mesh_config(wrapper: ParseConfigWrapper) -> BedMeshConfig:
         probe_count=list_to_tuple(wrapper.get_required_int_list("probe_count", count=2)),
         speed=wrapper.get_float("speed", default=50, minimum=1),
         horizontal_move_z=wrapper.get_float("horizontal_move_z", default=4, minimum=1),
-        adaptive_margin=wrapper.get_float("adaptive_margin", default=0, minimum=0),
+        adaptive_margin=wrapper.get_float("adaptive_margin", default=5, minimum=0),
         zero_reference_position=list_to_tuple(wrapper.get_required_float_list("zero_reference_position", count=2)),
     )
 
