@@ -9,7 +9,7 @@ if TYPE_CHECKING:
 HomingAxis = Literal["x", "y", "z"]
 
 
-@dataclass
+@dataclass(frozen=True)
 class Position:
     x: float
     y: float
@@ -111,6 +111,8 @@ class ProbeMode(Protocol):
     def offset(self) -> Position: ...
     @property
     def is_ready(self) -> bool: ...
+    @property
+    def last_homing_time(self) -> float: ...
     def get_status(self, eventtime: float) -> object: ...
     def perform_probe(self) -> float: ...
 
@@ -153,8 +155,8 @@ class Toolhead(Protocol):
         """Set the z position of the toolhead."""
         ...
 
-    def get_z_axis_limits(self) -> tuple[float, float]:
-        """Get the limits of the z axis."""
+    def get_axis_limits(self, axis: HomingAxis) -> tuple[float, float]:
+        """Get the limits of an axis."""
         ...
 
     def manual_probe(self, finalize_callback: Callable[[Position | None], None]) -> None:
