@@ -37,7 +37,7 @@ class ScanCalibrateMacro(Macro):
 
     @override
     def run(self, params: MacroParams) -> None:
-        name = params.get("MODEL_NAME", DEFAULT_SCAN_MODEL_NAME)
+        name = params.get("MODEL", DEFAULT_SCAN_MODEL_NAME).lower()
         method = get_enum_choice(params, "METHOD", ScanCalibrateMethod, default=ScanCalibrateMethod.MANUAL)
 
         if not self._toolhead.is_homed("x") or not self._toolhead.is_homed("y"):
@@ -61,11 +61,11 @@ class ScanCalibrateMacro(Macro):
     def _run_touch(self, name: str) -> None:
         trigger_pos = self._probe.perform_touch()
         pos = self._toolhead.get_position()
-        self._toolhead.set_z_position(pos.z - (trigger_pos - self._probe.touch.offset.z))
+        self._toolhead.set_z_position(pos.z - trigger_pos)
         self._calibrate(name)
 
     def _run_manual(self, name: str) -> None:
-        _, z_max = self._toolhead.get_z_axis_limits()
+        _, z_max = self._toolhead.get_axis_limits("z")
         self._toolhead.set_z_position(z=z_max - 10)
 
         logger.info("Triggering manual probe, please bring nozzle to 0.1mm above the bed")
