@@ -6,7 +6,7 @@ from typing import TYPE_CHECKING, final
 import numpy as np
 from typing_extensions import override
 
-from cartographer.interfaces.printer import Macro, MacroParams
+from cartographer.interfaces.printer import HomingState, Macro, MacroParams
 from cartographer.lib.statistics import compute_mad
 
 if TYPE_CHECKING:
@@ -18,7 +18,7 @@ logger = logging.getLogger(__name__)
 
 
 @final
-class TouchMacro(Macro):
+class TouchProbeMacro(Macro):
     description = "Touch the bed to get the height offset at the current position."
     last_trigger_position: float | None = None
 
@@ -48,7 +48,7 @@ class TouchAccuracyMacro(Macro):
         position = self._toolhead.get_position()
 
         logger.info(
-            "TOUCH_ACCURACY at X:%.3f Y:%.3f Z:%.3f (samples=%d retract=%.3f lift_speed=%.1f)",
+            "touch accuracy at X:%.3f Y:%.3f Z:%.3f (samples=%d retract=%.3f lift_speed=%.1f)",
             position.x,
             position.y,
             position.z,
@@ -91,6 +91,16 @@ class TouchAccuracyMacro(Macro):
         )
 
 
+class _FakeHomingState(HomingState):
+    @override
+    def is_homing_z(self) -> bool:
+        return True
+
+    @override
+    def set_z_homed_position(self, position: float) -> None:
+        pass
+
+
 @final
 class TouchHomeMacro(Macro):
     description = "Touch the bed to home Z axis"
@@ -114,7 +124,7 @@ class TouchHomeMacro(Macro):
         forced_z = False
         if not self._toolhead.is_homed("z"):
             forced_z = True
-            _, z_max = self._toolhead.get_z_axis_limits()
+            _, z_max = self._toolhead.get_axis_limits("z")
             self._toolhead.set_z_position(z=z_max - 10)
 
         pos = self._toolhead.get_position()
@@ -138,6 +148,8 @@ class TouchHomeMacro(Macro):
 
         pos = self._toolhead.get_position()
         self._toolhead.set_z_position(pos.z - trigger_pos)
+        # Simulate home end to update last homing time
+        self._probe.on_home_end(_FakeHomingState())
         logger.info(
             "Touch home at (%.3f,%.3f) adjusted z by %.3f",
             pos.x,
