@@ -147,7 +147,7 @@ class TouchCalibrateMacro(Macro):
 
     @override
     def run(self, params: MacroParams) -> None:
-        name = params.get("MODEL_NAME", DEFAULT_TOUCH_MODEL_NAME)
+        name = params.get("MODEL", DEFAULT_TOUCH_MODEL_NAME).lower()
         speed = params.get_int("SPEED", default=3, minval=1, maxval=5)
         threshold_start = params.get_int("START", default=500, minval=100)
         threshold_max = params.get_int("MAX", default=3000, minval=threshold_start)
@@ -186,7 +186,7 @@ class TouchCalibrateMacro(Macro):
         try:
             if not self._toolhead.is_homed("z"):
                 forced_z = True
-                _, z_max = self._toolhead.get_z_axis_limits()
+                _, z_max = self._toolhead.get_axis_limits("z")
                 self._toolhead.set_z_position(z=z_max - 10)
 
             threshold = self._find_acceptable_threshold(calibration_mode, threshold_start, threshold_max)
@@ -199,7 +199,7 @@ class TouchCalibrateMacro(Macro):
                 """
                 Failed to calibrate with %s strategy (thresholds %d-%d).
                 Try increasing MAX or changing strategy.
-                TOUCH_CALIBRATE START=%d MAX=%d
+                CARTOGRAPHER_TOUCH_CALIBRATE START=%d MAX=%d
                 """,
                 strategy_type,
                 threshold_start,
@@ -214,6 +214,7 @@ class TouchCalibrateMacro(Macro):
         )
         model = TouchModelConfiguration(name, threshold, speed, DEFAULT_Z_OFFSET)
         self._config.save_touch_model(model)
+        self._probe.touch.load_model(name)
         logger.info(
             """
             Touch model %s has been saved for the current session.
