@@ -60,14 +60,18 @@ class ScanMode(ScanModelSelectorMixin, ProbeMode, Endstop):
     @property
     @override
     def offset(self) -> Position:
-        z_offset = self.get_model().z_offset if self.has_model() else 0.0
-        return Position(self._config.x_offset, self._config.y_offset, self.probe_height + z_offset)
+        return Position(self._config.x_offset, self._config.y_offset, self.probe_height)
 
     @property
     @override
     def is_ready(self) -> bool:
         return self.has_model()
 
+    @property
+    @override
+    def last_homing_time(self) -> float:
+        return self._last_homing_time
+
     def __init__(
         self,
         mcu: Mcu,
@@ -75,6 +79,7 @@ class ScanMode(ScanModelSelectorMixin, ProbeMode, Endstop):
         config: ScanModeConfiguration,
     ) -> None:
         super().__init__(config.models)
+        self._last_homing_time: float = 0.0
         self._toolhead: Toolhead = toolhead
         self._config: ScanModeConfiguration = config
         self.probe_height: float = TRIGGER_DISTANCE
@@ -158,11 +163,12 @@ class ScanMode(ScanModelSelectorMixin, ProbeMode, Endstop):
         if not homing_state.is_homing_z():
             return
         distance = self.measure_distance()
-        if math.isinf(distance):
+        if not math.isfinite(distance):
             msg = "Toolhead stopped outside model range"
             raise RuntimeError(msg)
 
         homing_state.set_z_homed_position(distance)
+        self._last_homing_time = self._toolhead.get_last_move_time()
 
     @override
     def home_wait(self, home_end_time: float) -> float:
