@@ -30,12 +30,12 @@ default_scan_config = ScanConfig(
     mesh_runs=1,
     mesh_direction="x",
     mesh_height=4.0,
-    mesh_corner_radius=2.0,
     mesh_path="snake",
 )
 default_touch_config = TouchConfig(
     samples=5,
     max_samples=10,
+    max_touch_temperature=150,
     models={},
 )
 default_bed_mesh_config = BedMeshConfig(
@@ -68,10 +68,18 @@ class MockConfiguration(Configuration):
     def save_scan_model(self, config: ScanModelConfiguration) -> None:
         self.scan.models[config.name] = config
 
+    @override
+    def remove_scan_model(self, name: str) -> None:
+        _ = self.scan.models.pop(name, None)
+
     @override
     def save_touch_model(self, config: TouchModelConfiguration) -> None:
         self.touch.models[config.name] = config
 
+    @override
+    def remove_touch_model(self, name: str) -> None:
+        _ = self.touch.models.pop(name, None)
+
     @override
     def save_z_backlash(self, backlash: float) -> None:
         self.general = replace(self.general, z_backlash=backlash)
